@@ -95,9 +95,12 @@ def display_table(results: Dict) -> None:
     """Display information"""
     for title, sect in results["sections"].items():
         print(title)
-        t = PrettyTable(sect["fields"])
+        fields = ["order"] + sect["fields"]
+        t = PrettyTable(fields)
         for row in sect["rows"]:
-            r = [row[field]["text"] for field in sect["fields"]]
+            r = [row["row_count"]] + [
+                row[field]["text"] for field in sect["fields"]
+            ]
             t.add_row(r)
         print(t, end="\n\n")
 
@@ -141,24 +144,21 @@ def process_financial_document(
     logging.info("Determining document structure")
 
     try:
-        document_structure, check_count = extract_contours_from_page(
-            pages, resize=resize_pdf
-        )
+        document_structure = extract_contours_from_page(pages, False)
     except:
+        logging.info("Failed")
         return {"success": False, "msg": CheckboxesNotFound}
 
-    if check_count < 8:
+    if document_structure["found_count"] < 8:
         logging.warning("Failed to extract document structure")
         return {
             "success": False,
             "msg": "Failed to process document properly",
-            "checkbox_count_found": check_count,
+            "checkbox_count_found": document_structure["found_count"],
         }
 
     logging.info("Extracting content from financial disclosure")
-    results = process_document(
-        document_structure, pages, show_logs, resize_pdf
-    )
+    results = process_document(document_structure, pages)
     results["page_count"] = page_total
     results["pdf_size"] = len(pdf_bytes)
     results["wealth"] = estimate_investment_net_worth(results)
@@ -170,7 +170,7 @@ def process_financial_document(
 
 
 def process_judicial_watch(
-    file_path=None, url=None, pdf_bytes=None, show_logs=None
+    file_path=None, url=None, pdf_bytes=None, show_logs=None, threaded=False
 ):
     """This is the second and more brute force method for ugly PDFs.
 
@@ -211,7 +211,7 @@ def process_judicial_watch(
     results = extract_section_I_to_VI(document_data, non_investment_pages)
 
     # Process Section VII
-    results = extract_section_VII(results, investment_pages)
+    results = extract_section_VII(results, investment_pages, threaded)
 
     # Process Section VIII - Addendum
     addendum_data = process_addendum(addendum_page)
@@ -236,6 +236,7 @@ def extract_financial_document(
     pdf_bytes: bytes = None,
     show_logs: bool = False,
     resize: bool = False,
+    threaded: bool = False,
 ) -> Dict:
     """Extract documents with lowered memory footprint
 
@@ -266,18 +267,24 @@ def extract_financial_document(
             pg = page.resize((1653, 2180))
             pages.append(pg)
 
-    document_structure = extract_contours_from_page(pages)
+    document_structure = extract_contours_from_page(pages, False, threaded)
 
     if document_structure["found_count"] < 8:
-        logging.warning("Failed to extract document structure")
-        return {
-            "success": False,
-            "msg": "Failed to process document properly",
-            "checkbox_count_found": document_structure["found_count"],
-        }
+        document_structure = extract_contours_from_page(pages, True, threaded)
+        # print(document_structure["found_count"])
+        if document_structure["found_count"] < 8:
+
+            logging.warning(
+                f"Failed to extract document structure {document_structure['found_count']}"
+            )
+            return {
+                "success": False,
+                "msg": "Failed to process document properly",
+                "checkbox_count_found": document_structure["found_count"],
+            }
 
     logging.info("Extracting content from financial disclosure")
-    results = process_document(document_structure, pages)
+    results = process_document(document_structure, pages, threaded)
     results["page_count"] = len(pages)
 
     results["pdf_size"] = ""
