@@ -64,6 +64,7 @@ def process_contours_page(
     s7: List,
     little_checkboxes: List,
     s1: List,
+    try_again: bool,
 ) -> Dict[str, Union[str, int, float, List, Dict]]:
 
     # Add to queue
@@ -89,7 +90,11 @@ def process_contours_page(
         extent = float(area) / rect_area
         aspect_ratio = float(w) / h
         if 0.9 <= aspect_ratio <= 1.1 and extent > 0.8 and x < width * 0.2:
-            if hierarchy[0, i, 3] == -1:
+            if not try_again:
+                move_on = True if hierarchy[0, i, 3] == -1 else False
+            else:
+                move_on = True if hierarchy[0, i, 3] > -1 else False
+            if move_on:
                 checkboxes_on_page.append((x, y, w, h, pg_num))
                 sect_order = (
                     len(checkboxes) + 1 if len(checkboxes) + 1 < 9 else 8
@@ -168,6 +173,8 @@ def process_contours_page(
         if w / h > 7 and w > 150 and y > min_y:
             # if hierarchy[0, i, 3] == -1:
             rect = (x, y, w, h, pg_num, range(y, y + h))
+            if not checkboxes:
+                return results
             section = determine_section_of_contour(checkboxes, rect)
             # section = section_dict[section]['name']
             rect = (x, y, w, h, pg_num, range(y, y + h), section)
@@ -216,7 +223,6 @@ def process_contours_page(
 
     # Release from queue
     sema.release()
-
     return results
 
 
@@ -297,8 +303,6 @@ def extract_other_data(results, check, other_sections):
                 (group["x"] + group["w"]),
                 (group["y"] + group["h"]),
             )
-            # print(results["sections"][sect]["fields"], col_indx)
-
             try:
                 column = results["sections"][sect]["fields"][col_indx]
                 results["sections"][sect]["rows"][row_index][column] = group
@@ -372,7 +376,7 @@ def group_other_sections(s1):
     return other_sections
 
 
-def extract_contours_from_page(pages: List[Image]):
+def extract_contours_from_page(pages: List[Image], try_again, threaded):
     """Process PDF
 
     Return the document structure as JSON data to easily and accurately
@@ -384,9 +388,13 @@ def extract_contours_from_page(pages: List[Image]):
     little_checkboxes = []
     threads = []
     pg_num = 0
+    if threaded:
+        start_at = 3
+    else:
+        start_at = len(pages)
     for page in pages:
 
-        if pg_num < 1:
+        if pg_num < start_at:
             results = process_contours_page(
                 page,
                 results,
@@ -397,6 +405,7 @@ def extract_contours_from_page(pages: List[Image]):
                 s7,
                 little_checkboxes,
                 s1,
+                try_again,
             )
         else:
             thread = threading.Thread(
@@ -411,9 +420,11 @@ def extract_contours_from_page(pages: List[Image]):
                     s7,
                     little_checkboxes,
                     s1,
+                    try_again,
                 ),
             )
             threads.append(thread)
+            thread.setDaemon(True)
             thread.start()
         pg_num += 1
 
